package sgc.portal.com.com.persistence;

import sgc.portal.base.util.EasyHashMap;
import sgc.portal.com.com.model.AuthGrp;
import sgc.portal.com.com.model.AuthUser;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;


/**
 * 프로그램 목록 매퍼  DAO
 *
 * @author KyungHee Jang(khjang@sgc.co.kr)
 * @version 1.0.0
 * @since  2020. 8. 2.
 */


@Mapper
public interface ComAuthUserMngMapper {

    List<EasyHashMap<String, Object>> selectComAuthGrpMng(AuthGrp authgrps);

    void insertComAuthGrpMng(AuthGrp authgrps);

    void updateComAuthGrpMng(AuthGrp authgrps);

    void deleteComAuthGrpMng(AuthGrp authgrps);

    List<EasyHashMap<String, Object>> selectComAuthUserMng(AuthUser authusers);

    List<EasyHashMap<String, Object>> selectComAuthUserNoMng(AuthUser authusers);

    void insertComAuthUserMng(AuthUser authusers);

    void updateComAuthUserMng(AuthUser authusers);

    void deleteComAuthUserMng(AuthUser authusers);
}

